==> PyCIM-14.15.1.tar.gz: PyCIM-14.15.1/CIM14/IEC61970/Generation/Production/__init__.py <==
# Copyright (C) 2010 Richard Lincoln
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA, USA

"""The production package is responsible for classes which describe various kinds of generators. These classes also provide production costing information which is used to economically allocate demand among committed units and calculate reserve quantities.
"""

nsPrefix = "cimProduction"
nsURI = "http://iec.ch/TC57/2009/CIM-schema-cim14#Production"

from CIM14.IEC61970.Generation.Production.LevelVsVolumeCurve import LevelVsVolumeCurve
from CIM14.IEC61970.Generation.Production.FossilFuel import FossilFuel
from CIM14.IEC61970.Generation.Production.SteamSendoutSchedule import SteamSendoutSchedule
from CIM14.IEC61970.Generation.Production.EmissionCurve import EmissionCurve
from CIM14.IEC61970.Generation.Production.CombinedCyclePlant import CombinedCyclePlant
from CIM14.IEC61970.Generation.Production.StartIgnFuelCurve import StartIgnFuelCurve
from CIM14.IEC61970.Generation.Production.HydroGeneratingEfficiencyCurve import HydroGeneratingEfficiencyCurve
from CIM14.IEC61970.Generation.Production.StartRampCurve import StartRampCurve
from CIM14.IEC61970.Generation.Production.GeneratingUnit import GeneratingUnit
from CIM14.IEC61970.Generation.Production.NuclearGeneratingUnit import NuclearGeneratingUnit
from CIM14.IEC61970.Generation.Production.WindGeneratingUnit import WindGeneratingUnit
from CIM14.IEC61970.Generation.Production.StartMainFuelCurve import StartMainFuelCurve
from CIM14.IEC61970.Generation.Production.StartupModel import StartupModel
from CIM14.IEC61970.Generation.Production.AirCompressor import AirCompressor
from CIM14.IEC61970.Generation.Production.HeatInputCurve import HeatInputCurve
from CIM14.IEC61970.Generation.Production.CogenerationPlant import CogenerationPlant
from CIM14.IEC61970.Generation.Production.ShutdownCurve import ShutdownCurve
from CIM14.IEC61970.Generation.Production.InflowForecast import InflowForecast
from CIM14.IEC61970.Generation.Production.HydroGeneratingUnit import HydroGeneratingUnit
from CIM14.IEC61970.Generation.Production.TargetLevelSchedule import TargetLevelSchedule
from CIM14.IEC61970.Generation.Production.EmissionAccount import EmissionAccount
from CIM14.IEC61970.Generation.Production.GrossToNetActivePowerCurve import GrossToNetActivePowerCurve
from CIM14.IEC61970.Generation.Production.HydroPumpOpSchedule import HydroPumpOpSchedule
from CIM14.IEC61970.Generation.Production.Reservoir import Reservoir
from CIM14.IEC61970.Generation.Production.CAESPlant import CAESPlant
from CIM14.IEC61970.Generation.Production.GenUnitOpCostCurve import GenUnitOpCostCurve
from CIM14.IEC61970.Generation.Production.PenstockLossCurve import PenstockLossCurve
from CIM14.IEC61970.Generation.Production.HydroPump import HydroPump
from CIM14.IEC61970.Generation.Production.GenUnitOpSchedule import GenUnitOpSchedule
from CIM14.IEC61970.Generation.Production.FuelAllocationSchedule import FuelAllocationSchedule
from CIM14.IEC61970.Generation.Production.HeatRateCurve import HeatRateCurve
from CIM14.IEC61970.Generation.Production.IncrementalHeatRateCurve import IncrementalHeatRateCurve
from CIM14.IEC61970.Generation.Production.ThermalGeneratingUnit import ThermalGeneratingUnit
from CIM14.IEC61970.Generation.Production.TailbayLossCurve import TailbayLossCurve
from CIM14.IEC61970.Generation.Production.HydroPowerPlant import HydroPowerPlant

==> PyCIM-14.15.2.tar.gz: PyCIM-14.15.2/CIM14/IEC61970/Generation/Production/__init__.py <==
# Copyright (C) 2010 Richard Lincoln
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA, USA

"""The production package is responsible for classes which describe various kinds of generators. These classes also provide production costing information which is used to economically allocate demand among committed units and calculate reserve quantities.
"""

nsPrefix = "cimProduction"
nsURI = "http://iec.ch/TC57/2009/CIM-schema-cim14#Production"

from CIM14.IEC61970.Generation.Production.LevelVsVolumeCurve import LevelVsVolumeCurve
from CIM14.IEC61970.Generation.Production.FossilFuel import FossilFuel
from CIM14.IEC61970.Generation.Production.SteamSendoutSchedule import SteamSendoutSchedule
from CIM14.IEC61970.Generation.Production.EmissionCurve import EmissionCurve
from CIM14.IEC61970.Generation.Production.CombinedCyclePlant import CombinedCyclePlant
from CIM14.IEC61970.Generation.Production.StartIgnFuelCurve import StartIgnFuelCurve
from CIM14.IEC61970.Generation.Production.HydroGeneratingEfficiencyCurve import HydroGeneratingEfficiencyCurve
from CIM14.IEC61970.Generation.Production.StartRampCurve import StartRampCurve
from CIM14.IEC61970.Generation.Production.GeneratingUnit import GeneratingUnit
from CIM14.IEC61970.Generation.Production.NuclearGeneratingUnit import NuclearGeneratingUnit
from CIM14.IEC61970.Generation.Production.WindGeneratingUnit import WindGeneratingUnit
from CIM14.IEC61970.Generation.Production.StartMainFuelCurve import StartMainFuelCurve
from CIM14.IEC61970.Generation.Production.StartupModel import StartupModel
from CIM14.IEC61970.Generation.Production.AirCompressor import AirCompressor
from CIM14.IEC61970.Generation.Production.HeatInputCurve import HeatInputCurve
from CIM14.IEC61970.Generation.Production.CogenerationPlant import CogenerationPlant
from CIM14.IEC61970.Generation.Production.ShutdownCurve import ShutdownCurve
from CIM14.IEC61970.Generation.Production.InflowForecast import InflowForecast
from CIM14.IEC61970.Generation.Production.HydroGeneratingUnit import HydroGeneratingUnit
from CIM14.IEC61970.Generation.Production.TargetLevelSchedule import TargetLevelSchedule
from CIM14.IEC61970.Generation.Production.EmissionAccount import EmissionAccount
from CIM14.IEC61970.Generation.Production.GrossToNetActivePowerCurve import GrossToNetActivePowerCurve
from CIM14.IEC61970.Generation.Production.HydroPumpOpSchedule import HydroPumpOpSchedule
from CIM14.IEC61970.Generation.Production.Reservoir import Reservoir
from CIM14.IEC61970.Generation.Production.CAESPlant import CAESPlant
from CIM14.IEC61970.Generation.Production.GenUnitOpCostCurve import GenUnitOpCostCurve
from CIM14.IEC61970.Generation.Production.PenstockLossCurve import PenstockLossCurve
from CIM14.IEC61970.Generation.Production.HydroPump import HydroPump
from CIM14.IEC61970.Generation.Production.GenUnitOpSchedule import GenUnitOpSchedule
from CIM14.IEC61970.Generation.Production.FuelAllocationSchedule import FuelAllocationSchedule
from CIM14.IEC61970.Generation.Production.HeatRateCurve import HeatRateCurve
from CIM14.IEC61970.Generation.Production.IncrementalHeatRateCurve import IncrementalHeatRateCurve
from CIM14.IEC61970.Generation.Production.ThermalGeneratingUnit import ThermalGeneratingUnit
from CIM14.IEC61970.Generation.Production.TailbayLossCurve import TailbayLossCurve
from CIM14.IEC61970.Generation.Production.HydroPowerPlant import HydroPowerPlant

class HydroPlantType(str):
    """The type of hydro power plant.
    Values are: runOfRiver, minorStorage, majorStorage, pumpedStorage
    """
    pass

class EmissionValueSource(str):
    """The source of the emission value.
    Values are: measured, calculated
    """
    pass

class GeneratorControlMode(str):
    """Unit control modes.
    Values are: setpoint, pulse
    """
    pass

class FuelType(str):
    """Type of fuel.
    Values are: lignite, coal, oil, gas
    """
    pass

class GeneratorControlSource(str):
    """The source of controls for a generating unit.
    Values are: unavailable, onAGC, plantControl, offAGC
    """
    pass

class HydroEnergyConversionKind(str):
    """Specifies the capability of the hydro generating unit to convert energy as a generator or pump.
    Values are: generator, pumpAndGenerator
    """
    pass

class SpillwayGateType(str):
    """Type of spillway gate.
    """
    pass

class SurgeTankCode(str):
    """Type (or absence) of surge tank that is associated with the hydro power plant.
    """
    pass

class EmissionType(str):
    """The type of emission
    Values are: chlorine, carbonDioxide, hydrogenSulfide, nitrogenOxide, sulfurDioxide, carbonDisulfide
    """
    pass

class GeneratorOperatingMode(str):
    """Operating mode for secondary generator control.
    Values are: fixed, EDC, manual, off, MRN, LFC, AGC, REG
    """
    pass

class PenstockType(str):
    """Type of hydro plant penstock.
    """
    pass

class Emission(float):
    """Quantity of emission per fuel heat content
    """
    pass

class HeatRate(float):
    """Heat generated, in energy pertime unit of elapsed time
    """
    pass

class Classification(int):
    """1..n, with 1 the most detailed, highest priority, etc.
    """
    pass

class CostPerHeatUnit(float):
    """Cost, in units of currency, per quantity of heat generated
    """
    pass
